@@ -1,7 +1,7 @@
 use proc_macro::TokenStream;
 use quote::{format_ident, quote};
 use std::str::FromStr;
-use syn::{parse_macro_input, Lit, MetaNameValue};
+use syn::{parse_macro_input, Lit, Meta, MetaNameValue};
 
 macro_rules! litstr {
     ($lit: expr) => {
@@ -54,6 +54,8 @@ pub fn sorting_derive(input: TokenStream) -> TokenStream {
                 } else {
                     panic!("invalid attribute")
                 }
+            } else {
+                panic!("invalid attribute")
             }
         }
     }
@@ -155,6 +157,7 @@ struct EnumVar {
     id: String,
     name: Option<String>,
     aliases: Vec<String>,
+    skip: bool,
 }
 
 impl EnumVar {
@@ -163,6 +166,7 @@ impl EnumVar {
             id: i.to_string(),
             name: None,
             aliases: Vec::new(),
+            skip: false,
         }
     }
 }
@@ -173,9 +177,11 @@ impl EnumVar {
 /// The possible case values: "lowercase", "UPPERCASE", "snake_case", "SCREAMING_SNAKE_CASE",
 /// "kebab-case", "SCREAMING-KEBAB-CASE".
 ///
-/// Individual fields can be overriden with enumstr(rename = "name"), altered with enumstr(alis =
+/// Individual fields can be overriden with enumstr(rename = "name"), altered with enumstr(alias =
 /// "alias")
 ///
+/// Fields, marked with enumstr(skip), are skipted in FromStr implementation.
+///
 /// To avoid additional dependancies, parse() Err type is String.
 ///
 /// # Panics
@@ -186,9 +192,12 @@ impl EnumVar {
 /// use bmart_derive::EnumStr;
 ///
 /// #[derive(EnumStr)]
+/// #[enumstr(rename_all = "snake_case")]
 /// enum MyEnum {
 ///     Field1,
 ///     Field2,
+///     #[enumstr(skip)]
+///     SecretField,
 ///     VeryLongField,
 ///     #[enumstr(rename = "another")]
 ///     #[enumstr(alias = "a")]
@@ -212,6 +221,14 @@ pub fn enumstr_derive(input: TokenStream) -> TokenStream {
                     } else {
                         panic!("invalid attribute")
                     }
+                } else if let Ok(name) = a.parse_args::<Meta>() {
+                    if name.path().is_ident("skip") {
+                        evar.skip = true;
+                    } else {
+                        panic!("invalid attribute")
+                    }
+                } else {
+                    panic!("invalid attribute")
                 }
             }
         }
@@ -227,6 +244,8 @@ pub fn enumstr_derive(input: TokenStream) -> TokenStream {
                 } else {
                     panic!("invalid attribute")
                 }
+            } else {
+                panic!("invalid attribute")
             }
         }
     }
@@ -239,11 +258,13 @@ pub fn enumstr_derive(input: TokenStream) -> TokenStream {
             format_case(&var.id, case)
         };
         st_to += &format!("{}::{} => \"{}\",", sid, var.id, name);
-        st_from += &format!("\"{}\"", name);
-        for alias in var.aliases {
-            st_from += &format!(" | \"{}\"", alias);
+        if !var.skip {
+            st_from += &format!("\"{}\"", name);
+            for alias in var.aliases {
+                st_from += &format!(" | \"{}\"", alias);
+            }
+            st_from += &format!(" => Ok({}::{}),", sid, var.id);
         }
-        st_from += &format!(" => Ok({}::{}),", sid, var.id);
     }
     st_to += "}";
     st_from += "_ => Err(\"value unsupported: \".to_owned() + s)}";
